==> odoo14_addon_pms-14.0.2.7.1.dev4-py3-none-any.whl: odoo/addons/pms/models/__init__.py <==
# Copyright 2018  Alexandre Díaz
# Copyright 2018  Dario Lodeiros
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).

from . import ir_http
from . import ir_config_parameter

# from . import payment_return
from . import pms_board_service_room_type
from . import pms_property
from . import res_users
from . import pms_ubication
from . import pms_folio
from . import pms_reservation
from . import pms_room
from . import pms_shared_room
from . import pms_amenity
from . import pms_amenity_type
from . import pms_room_type
from . import pms_service
from . import account_move
from . import product_template
from . import product_product
from . import res_company
from . import account_payment
from . import pms_availability_plan
from . import pms_availability_plan_rule
from . import pms_reservation_line
from . import pms_checkin_partner
from . import product_pricelist
from . import product_pricelist_item
from . import res_partner
from . import pms_sale_channel

# from . import mail_compose_message
from . import pms_room_type_class
from . import pms_room_closure_reason
from . import pms_service_line
from . import pms_board_service
from . import pms_board_service_room_type_line
from . import pms_board_service_line
from . import account_move_line
from . import pms_cancelation_rule
from . import folio_sale_line
from . import account_bank_statement_line
from . import account_bank_statement
from . import account_journal
from . import pms_availability
from . import res_partner_id_number

==> odoo14_addon_pms-14.0.2.18.2.dev9-py3-none-any.whl: odoo/addons/pms/models/__init__.py <==
# Copyright 2018  Alexandre Díaz
# Copyright 2018  Dario Lodeiros
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl).

from . import ir_http
from . import ir_config_parameter

# from . import payment_return
from . import pms_board_service_room_type
from . import pms_property
from . import res_users
from . import pms_ubication
from . import pms_folio
from . import pms_reservation
from . import pms_room
from . import pms_amenity
from . import pms_amenity_type
from . import pms_room_type
from . import pms_service
from . import account_move
from . import product_template
from . import product_product
from . import res_company
from . import account_payment
from . import pms_availability_plan
from . import pms_availability_plan_rule
from . import pms_reservation_line
from . import pms_checkin_partner
from . import product_pricelist
from . import product_pricelist_item
from . import res_partner
from . import pms_sale_channel

from . import mail_compose_message
from . import pms_room_type_class
from . import pms_room_closure_reason
from . import pms_service_line
from . import pms_board_service
from . import pms_board_service_room_type_line
from . import pms_board_service_line
from . import account_move_line
from . import pms_cancelation_rule
from . import folio_sale_line
from . import account_bank_statement_line
from . import account_bank_statement
from . import account_journal
from . import pms_availability
from . import res_partner_id_number
from . import pms_automated_mails
